#' Function to combine landscape and class data
#' 
#' This function combines FRAGSTATS landscape (.land) and class (.class) output
#' files into a single wide format dataset.
#' 
#' This functions takes corresponding FRAGSTATS landscape (.land) and class
#' (.class) output files and combines them into a single wide format file with
#' a single row for each unique input landscape (LID). The class metrics are
#' assigned names by combining the class name (TYPE) with each class metric and
#' assigned to a column. Thus, a single landscape containing 10 classes and 5
#' class metrics will produce a data frame containing 50 columns (variables)
#' for the factorial combination of classes and class metrics, and these will
#' be added to the columns containing the landscape metrics. If the input files
#' contain multiple landscape, the output file will contain a single row for
#' each input landscape.
#' 
#' Note, any class (TYPE) missing from any input landscape (LID) will be
#' assigned 'NA' for the class metrics in the resulting data frame, and thus
#' attention to these missing values may be needed prior to using the dataframe
#' in subsequent analyses.
#' 
#' @usage frag.combine(path,inland,inclass,outfile=NULL)
#' 
#' @param path complete path (in quotes with forward slashes to designate
#' subdirectories) to the directory containing the FRAGSTATS landscape (.land)
#' and class (.class) output files.
#' @param inland name of the FRAGSTATS landscape (.land) file (in quotes).
#' @param inclass name of the FRAGSTATS class (.class) file (in quotes).
#' @param outfile optional output file name that will be saved as a
#' comma-delimited ascii (.csv) file in the directory specified by the path.
#' Note, do not include the .csv extension with the file name (see example).
#' 
#' @return This function returns a data frame containing a single row for each 
#' unique input landscape (LID) and columns containing each of the landscape 
#' metrics and each combination of class (TYPE) and class metric.
#' 
#' @author Michael L. Treglia (modified by K. McGarigal)
#' 
#' @references http://www.umass.edu/landeco/research/fragstats/fragstats.html
#' 
#' @keywords FRAGSTATS
#' 
#' @examples 
#' path<-system.file("extdata",package="Rfrag")
#' frag.combine(path=path,inland='fragout.land',
#'   inclass='fragout.class',outfile='fragnew')
#' 
#' @export frag.combine

frag.combine<-function(path,inland,inclass,outfile=NULL){

#enforce backslash at end of path if not provided
path <- gsub("[/\\\\]*$", "/", path)

#import fragstats output
classes<-read.csv(paste(path,inclass,sep=''),strip.white=TRUE,na.strings='N/A')
land<-read.csv(paste(path,inland,sep=''),strip.white=TRUE,na.strings='N/A')

#Split the Class Results into different datasets, by the classes
indiv.classes <- split(classes, as.factor(classes$TYPE))

#Rename Columns for the Class variables to correspond with specific classes
for(i in names(indiv.classes)){
  colnames(indiv.classes[[i]])<-c("LID","TYPE",paste(colnames(indiv.classes[[i]][,3:ncol(indiv.classes[[i]])]),i,sep="."))
}

#Create copy of "land", naming it to "x", but as a dataset list
x<-list(land) 

#Merge the datasets for each class into a single dataset
for (i in 1:length(indiv.classes)){
  x[[i+1]]<-merge(x[[i]], indiv.classes[[i]][,-2], by="LID", all=T)
  z<-data.frame(x[[length(x)]]) 
}

#save output file to disk
if(!is.null(outfile)){
  write.csv(z,paste(path,outfile,'.csv',sep=''),row.names=FALSE)
}

return(z)
}
